@@ -105,6 +105,15 @@ public class DefaultUserContextTest {
         assertTrue(victim.isUseSmartOutput());
     }
 
+    @Test
+    public void isAskClearConfirmation() {
+        assertTrue(victim.isAskClearConfirmation());
+        victim.setBooleanPreference(BooleanUserPreference.CLEAR_CONFIRMATION, false);
+        assertFalse(victim.isAskClearConfirmation());
+        victim.setBooleanPreference(BooleanUserPreference.CLEAR_CONFIRMATION, true);
+        assertTrue(victim.isAskClearConfirmation());
+    }
+
     @Test
     public void isAskPlaySounds() {
         victim.setBooleanPreference(BooleanUserPreference.PLAY_SOUNDS, true);
@@ -113,6 +122,40 @@ public class DefaultUserContextTest {
         assertFalse(victim.isPlaySounds());
     }
 
+    @Test
+    public void isCompressionEnabled() {
+        victim.setBooleanPreference(BooleanUserPreference.PDF_COMPRESSION_ENABLED, true);
+        assertTrue(victim.isCompressionEnabled());
+        victim.setBooleanPreference(BooleanUserPreference.PDF_COMPRESSION_ENABLED, false);
+        assertFalse(victim.isCompressionEnabled());
+    }
+
+    @Test
+    public void isCompressionEnabledSystemDefault() {
+        System.setProperty(DefaultUserContext.PDF_COMPRESSION_PROP, "false");
+        assertFalse(victim.isCompressionEnabled());
+        victim.setBooleanPreference(BooleanUserPreference.PDF_COMPRESSION_ENABLED, true);
+        assertTrue(victim.isCompressionEnabled());
+        System.clearProperty(DefaultUserContext.PDF_COMPRESSION_PROP);
+    }
+
+    @Test
+    public void isOverwriteOutput() {
+        victim.setBooleanPreference(BooleanUserPreference.OVERWRITE_OUTPUT, true);
+        assertTrue(victim.isOverwriteOutput());
+        victim.setBooleanPreference(BooleanUserPreference.OVERWRITE_OUTPUT, false);
+        assertFalse(victim.isOverwriteOutput());
+    }
+
+    @Test
+    public void isOverwriteOutputSystemDefault() {
+        System.setProperty(DefaultUserContext.OVERWRITE_OUTPUT_PROP, "true");
+        assertTrue(victim.isOverwriteOutput());
+        victim.setBooleanPreference(BooleanUserPreference.OVERWRITE_OUTPUT, false);
+        assertFalse(victim.isOverwriteOutput());
+        System.clearProperty(DefaultUserContext.OVERWRITE_OUTPUT_PROP);
+    }
+
     @Test
     public void isPlaySoundsSystemDefault() {
         System.setProperty(DefaultUserContext.PLAY_SOUNDS_PROP, "false");
@@ -212,4 +255,23 @@ public class DefaultUserContextTest {
         victim.setIntegerPreference(IntUserPreference.LOGVIEW_ROWS_NUMBER, 20);
         assertEquals(20, victim.getNumberOfLogRows());
     }
+
+    @Test
+    public void getDefaultPrefix() {
+        victim.setDefaultPrefix("module", "banana");
+        assertEquals("banana", victim.getDefaultPrefix("module"));
+        assertEquals("PDFsam_", victim.getDefaultPrefix("module_2"));
+        victim.setDefaultPrefix("module", "");
+        assertEquals("", victim.getDefaultPrefix("module"));
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void getDefaultPrefixEmptyModule() {
+        victim.getDefaultPrefix(" ");
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void getDefaultPrefixNullModule() {
+        victim.getDefaultPrefix(null);
+    }
 }
