@@ -31,6 +31,7 @@ import java.util.HashMap;
 
 import org.junit.Before;
 import org.junit.Test;
+import org.sejda.conversion.exception.ConversionException;
 import org.sejda.model.input.PdfFileSource;
 import org.sejda.model.pdf.PdfVersion;
 
@@ -111,6 +112,12 @@ public class PdfDocumentDescriptorTest {
         assertEquals("pwd", source.getPassword());
     }
 
+    @Test(expected = ConversionException.class)
+    public void FailToPdfSource() {
+        when(file.isFile()).thenReturn(Boolean.FALSE);
+        victim.toPdfFileSource();
+    }
+
     @Test
     public void informationDictionary() {
         HashMap<String, String> values = new HashMap<>();
