@@ -18,15 +18,15 @@
  */
 package org.pdfsam.ui.dashboard;
 
-import static org.pdfsam.support.RequireUtils.requireNotNull;
 import static org.pdfsam.ui.commons.SetActiveModuleRequest.activeteCurrentModule;
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.sejda.commons.util.RequireUtils.requireNotNullArg;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import org.pdfsam.i18n.DefaultI18nContext;
 import org.pdfsam.ui.commons.SetActiveModuleRequest;
 import org.pdfsam.ui.support.Style;
-import org.sejda.eventstudio.Listener;
-import org.sejda.eventstudio.ReferenceStrength;
+import org.pdfsam.eventstudio.Listener;
+import org.pdfsam.eventstudio.ReferenceStrength;
 
 import javafx.scene.control.Button;
 import javafx.scene.control.ScrollPane;
@@ -50,7 +50,7 @@ class DashboardItemPane extends BorderPane {
     };
 
     DashboardItemPane(DashboardItem item) {
-        requireNotNull(item, "Dashboard item cannot be null");
+        requireNotNullArg(item, "Dashboard item cannot be null");
         this.item = item;
         this.item.pane().getStyleClass().addAll(Style.DEAULT_CONTAINER.css());
         this.item.pane().getStyleClass().addAll(Style.CONTAINER.css());
