@@ -18,7 +18,7 @@
  */
 package org.pdfsam.ui.workarea;
 
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import java.util.HashMap;
 import java.util.List;
@@ -27,12 +27,13 @@ import java.util.Optional;
 
 import javax.inject.Inject;
 
+import org.pdfsam.eventstudio.annotation.EventListener;
 import org.pdfsam.module.Module;
 import org.pdfsam.ui.commons.SetActiveModuleRequest;
 import org.pdfsam.ui.event.SetTitleEvent;
+import org.pdfsam.ui.module.RunButtonTriggerRequest;
 import org.pdfsam.ui.quickbar.QuickbarPane;
 import org.pdfsam.ui.support.Style;
-import org.sejda.eventstudio.annotation.EventListener;
 
 import javafx.animation.FadeTransition;
 import javafx.scene.control.ScrollPane;
@@ -82,4 +83,11 @@ public class WorkArea extends BorderPane {
         });
         eventStudio().broadcast(new SetTitleEvent(current.map(m -> m.descriptor().getName()).orElse("")));
     }
+
+    @EventListener
+    public void onRunButtonAccelerator(RunButtonTriggerRequest request) {
+        if (this.isVisible()) {
+            current.ifPresent(m -> eventStudio().broadcast(request, m.id()));
+        }
+    }
 }
\ No newline at end of file
