@@ -20,7 +20,7 @@ package org.pdfsam.module;
 
 import static java.util.stream.Collectors.toList;
 import static org.apache.commons.lang3.StringUtils.isNotBlank;
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -30,11 +30,12 @@ import java.util.prefs.BackingStoreException;
 import java.util.prefs.Preferences;
 
 import org.pdfsam.ShutdownEvent;
-import org.sejda.eventstudio.annotation.EventListener;
+import org.pdfsam.eventstudio.annotation.EventListener;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.fasterxml.jackson.jr.ob.JSON;
+import com.fasterxml.jackson.jr.ob.JSON.Feature;
 
 /**
  * @author Andrea Vacondio
@@ -45,6 +46,7 @@ class PreferencesUsageDataStore {
     static final String USAGE_PATH = "/org/pdfsam/modules/usage";
     static final String MODULE_USAGE_KEY = "module.usage";
     static final String TASKS_EXECUTED_KEY = "tasks.executed";
+    private JSON jackson = new JSON().without(Feature.USE_FIELDS);
 
     public PreferencesUsageDataStore() {
         eventStudio().addAnnotatedListeners(this);
@@ -55,9 +57,9 @@ class PreferencesUsageDataStore {
         String json = node.get(MODULE_USAGE_KEY, "");
         try {
             if (isNotBlank(json)) {
-                node.put(MODULE_USAGE_KEY, JSON.std.asString(JSON.std.beanFrom(ModuleUsage.class, json).inc()));
+                node.put(MODULE_USAGE_KEY, jackson.asString(jackson.beanFrom(ModuleUsage.class, json).inc()));
             } else {
-                node.put(MODULE_USAGE_KEY, JSON.std.asString(ModuleUsage.fistUsage(moduleId)));
+                node.put(MODULE_USAGE_KEY, jackson.asString(ModuleUsage.fistUsage(moduleId)));
             }
             LOG.trace("Usage incremented for module {}", moduleId);
         } catch (IOException e) {
@@ -74,7 +76,7 @@ class PreferencesUsageDataStore {
             List<String> jsons = Arrays.stream(prefs.childrenNames()).parallel().map(name -> prefs.node(name))
                     .map(node -> node.get(MODULE_USAGE_KEY, "")).filter(json -> isNotBlank(json)).collect(toList());
             for (String json : jsons) {
-                retList.add(JSON.std.beanFrom(ModuleUsage.class, json));
+                retList.add(jackson.beanFrom(ModuleUsage.class, json));
             }
         } catch (BackingStoreException | IOException e) {
             LOG.error("Unable to get modules usage statistics", e);
